module.exports = {
  "parser": "@typescript-eslint/parser",
  "parserOptions": {
    "ecmaVersion": 2018,
    "ecmaFeatures": {
      "jsx": true
    },
    "sourceType": "module"
  },
  "env": {
    "es6": true,
    "commonjs": true,
    "browser": true,
    "node": true,
    "mocha": true,
    "jest": true,
    "cypress/globals": true
  },
  "plugins": [
    "cypress",
    "jsx-a11y",
    "jest",
    "testing-library"
  ],
  "globals": {
    "document": false,
    "navigator": false,
    "window": false,
    "cy": false,
    "Cypress": false
  },
  "extends": [
    "standard",
    "plugin:@typescript-eslint/recommended",
    "plugin:jsx-a11y/recommended",
    "plugin:react/recommended",
    "plugin:jest/recommended",
    "plugin:testing-library/react",
    "plugin:react-hooks/recommended",
    "plugin:prettier/recommended"
  ],
  "rules": {
    // TypeScript rules
    "@typescript-eslint/ban-types": 0,
    "@typescript-eslint/camelcase": 0,
    "@typescript-eslint/explicit-function-return-type": 0,
    "@typescript-eslint/explicit-member-accessibility": 0,
    "@typescript-eslint/explicit-module-boundary-types": 0,
    "@typescript-eslint/no-non-null-assertion": 0,
    "@typescript-eslint/no-unused-vars": 0,
    "@typescript-eslint/array-type": 0,
    "@typescript-eslint/no-explicit-any": 0,
    "@typescript-eslint/no-empty-interface": 0,
    "@typescript-eslint/no-use-before-define": 0,
    "@typescript-eslint/no-object-literal-type-assertion": 0,
    "@typescript-eslint/no-var-requires": 0,
    "@typescript-eslint/prefer-as-const": 0,

    // standard rules
    "camelcase": 0,
    "no-console": 1,
    "no-undef": 0, // disabled due to false positives when exporting interfaces; the ts compiler catches this for us
    "no-use-before-define": 0, // this rule clashes with 'import React' statements
    "prefer-template": 2,
    "quotes": [2, "single", { "avoidEscape": true }],
    "require-await": 2,
    "generator-star-spacing": [
      2,
      {
        "before": false,
        "after": true
      }
    ],
    "space-before-function-paren": [
      2,
      {
        "asyncArrow": "always",
        "anonymous": "never",
        "named": "never"
      }
    ],

    // import rules
    "import/order": [
      2,
      {
        "groups": ["builtin", "external", "internal", ["parent", "sibling"], "index"],
        "newlines-between": "never"
      }
    ],

    // React rules
    "react/no-deprecated": 0,
    "react/prop-types": 0,
    "react/jsx-curly-brace-presence": [2, "never"],
    "react/jsx-filename-extension": [
      1, { "extensions": [".tsx", ".jsx"]}
    ],
    "react/no-array-index-key": 1,

    // testing library
    "testing-library/no-container": 0,
    "testing-library/no-node-access": 0,
    "testing-library/prefer-screen-queries": 1,

    // Jest rules
    "jest/no-mocks-import": 0,
    "jest/no-done-callback": 0,
    "jest/valid-expect": 0, // enabling this would throw 2s for 'expect(content)' statements without verbose matchers

    // import rules
    "no-restricted-imports": [
      "error",
      {
        "paths": [
          { "name": "@guildeducationinc/recess-icons", "message": "no named import from recess icons" },
          { "name": "@mui/icons-material", "message": "no named import from material icons" }
        ]
      }
    ]
  },
  "settings":  {
    "react":  {
      "version":  "detect"
    }
  }
}
